@@ -20,10 +20,12 @@ from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
 from zope.traversing.interfaces import ITraversable
 
 from pyams_layer.interfaces import IPyAMSLayer
-from pyams_portal.interfaces import IPortalContext, IPortalPage, IPortalTemplateConfiguration, \
+from pyams_portal.interfaces import IPortalContext, IPortalContextIndexPage, IPortalPage, \
+    IPortalTemplateConfiguration, \
     IPortlet, IPortletRenderer, IPortletRendererSettings, IPortletSettings, \
     PORTLET_RENDERERS_VOCABULARY, PORTLET_RENDERER_SETTINGS_KEY, PREVIEW_MODE
 from pyams_portal.portlet import LOGGER
+from pyams_portal.utils import get_portal_page
 from pyams_utils.adapter import ContextAdapter, adapter_config, get_adapter_weight, \
     get_annotation_adapter
 from pyams_utils.cache import get_cache
@@ -41,8 +43,8 @@ from pyams_portal import _  # pylint: disable=ungrouped-imports
 PORTLETS_CACHE_NAME = 'portlets'
 PORTLETS_CACHE_REGION = 'portlets'
 PORTLETS_CACHE_NAMESPACE = 'PyAMS::portlet'
-PORTLETS_CACHE_KEY = 'portlet::{hostname}::{portlet}::{context}::{lang}'
-PORTLETS_CACHE_DISPLAY_CONTEXT_KEY = 'portlet::{hostname}::{portlet}:' \
+PORTLETS_CACHE_KEY = 'portlet::{scheme}::{hostname}::{portlet}::{context}::{lang}'
+PORTLETS_CACHE_DISPLAY_CONTEXT_KEY = 'portlet::{scheme}::{hostname}::{portlet}:' \
                                      ':{context}::{display}::{lang}'
 
 
@@ -79,7 +81,7 @@ class PortletRenderer(PortletContentProvider):
     @property
     def settings_key(self):
         """Settings annotation key getter"""
-        return PORTLET_RENDERER_SETTINGS_KEY.format(self.settings.renderer)
+        return f'{PORTLET_RENDERER_SETTINGS_KEY}::{self.settings.renderer}'
 
     target_interface = None
     use_authentication = False
@@ -89,7 +91,11 @@ class PortletRenderer(PortletContentProvider):
     @property
     def slot_configuration(self):
         """Slot configuration getter"""
-        template = IPortalPage(self.context).template
+        index_page = IPortalContextIndexPage(self.view, None)
+        if index_page is not None:
+            template = self.view.page.template
+        else:
+            template = get_portal_page(self.context).template
         config = IPortalTemplateConfiguration(template)
         _slot_id, slot_name = config.get_portlet_slot(self.settings.configuration.portlet_id)
         return config.get_slot_configuration(slot_name)
@@ -103,11 +109,13 @@ class PortletRenderer(PortletContentProvider):
         """Cache key getter"""
         display_context = get_display_context(self.request)
         if display_context is None:
-            return PORTLETS_CACHE_KEY.format(hostname=self.request.host,
+            return PORTLETS_CACHE_KEY.format(scheme=self.request.scheme,
+                                             hostname=self.request.host,
                                              portlet=ICacheKeyValue(self.settings),
                                              context=ICacheKeyValue(self.context),
                                              lang=self.request.locale_name)
-        return PORTLETS_CACHE_DISPLAY_CONTEXT_KEY.format(hostname=self.request.host,
+        return PORTLETS_CACHE_DISPLAY_CONTEXT_KEY.format(scheme=self.request.scheme,
+                                                         hostname=self.request.host,
                                                          portlet=ICacheKeyValue(self.settings),
                                                          context=ICacheKeyValue(self.context),
                                                          display=ICacheKeyValue(display_context),
@@ -122,18 +130,20 @@ class PortletRenderer(PortletContentProvider):
                                    PORTLETS_CACHE_NAMESPACE)
         cache_key = self.get_cache_key()
         if template_name:
-            cache_key = '{}::{}'.format(cache_key, template_name)
+            cache_key = f'{cache_key}::{template_name}'
         if self.use_authentication:
-            cache_key = '{}::{}'.format(cache_key, self.request.principal.id)
+            cache_key = f'{cache_key}::{self.request.principal.id}'
         # load rendered content from cache, or create output and store it in cache
         try:
             result = portlets_cache.get_value(cache_key)
-            LOGGER.debug("Retrieving portlet content from cache key {0}".format(cache_key))
+            LOGGER.debug(f"Retrieved portlet content from cache key {cache_key}")
+            if result:
+                self.get_resources()
         except KeyError:
             self.update()
             result = super().render(template_name)
             portlets_cache.set_value(cache_key, result)
-            LOGGER.debug("Storing portlet content to cache key {0}".format(cache_key))
+            LOGGER.debug(f"Storing portlet content to cache key {cache_key}")
         return result
 
 
@@ -154,7 +164,8 @@ class PortletRenderersVocabulary(SimpleVocabulary):
         super().__init__(terms)
 
 
-@adapter_config(required=IPortletSettings, provides=IPortletRendererSettings)
+@adapter_config(required=IPortletSettings,
+                provides=IPortletRendererSettings)
 def portlet_renderer_settings_adapter(context):
     """Portlet renderer settings adapter"""
     renderer = context.get_renderer()
@@ -165,7 +176,8 @@ def portlet_renderer_settings_adapter(context):
 
 
 @adapter_config(name='renderer',
-                required=IPortletSettings, provides=ITraversable)
+                required=IPortletSettings,
+                provides=ITraversable)
 class PortletSettingsRendererSettingsTraverser(ContextAdapter):
     """Portlet settings traverser to renderer settings"""
 
@@ -179,13 +191,13 @@ class PortletSettingsRendererSettingsTraverser(ContextAdapter):
 #
 
 @adapter_config(name='hidden',
-                context=(IPortalContext, IPyAMSLayer, Interface, IPortletSettings),
+                required=(IPortalContext, IPyAMSLayer, Interface, IPortletSettings),
                 provides=IPortletRenderer)
 class HiddenPortletRenderer(PortletRenderer):
     """Hidden portlet renderer"""
 
     label = _("Hidden portlet")
-    weight = 9999
+    weight = -999
 
     def render(self, template_name=''):
         return ''
